# This is a cryptografy module that encrypt any string that you put ou decrypt it on my own cryptografy.

# You can use this for anything you want

# The name of this cryptografy is 'ions'.

# Made in Brazil, 2023
# Version: 1
# Day: 02/18/2023
# Made in python for PyPI
# pip install ions